==> xs2a-impl-2.13-sources.jar: de/adorsys/psd2/xs2a/web/validator/PaymentMethodValidatorImpl.java <==
/*
 * Copyright 2018-2019 adorsys GmbH & Co KG
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package de.adorsys.psd2.xs2a.web.validator;

import de.adorsys.psd2.xs2a.web.validator.body.payment.PaymentBodyValidator;
import de.adorsys.psd2.xs2a.web.validator.body.raw.PaymentRawBodyValidator;
import de.adorsys.psd2.xs2a.web.validator.header.PaymentHeaderValidator;
import de.adorsys.psd2.xs2a.web.validator.query.QueryParameterValidator;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.Collections;
import java.util.List;

@Component
public class PaymentMethodValidatorImpl extends AbstractMethodValidator<PaymentHeaderValidator, PaymentRawBodyValidator, PaymentBodyValidator, QueryParameterValidator> {

    private static final String METHOD_NAME = "_initiatePayment";

    @Autowired
    protected PaymentMethodValidatorImpl(List<PaymentHeaderValidator> headerValidators,
                                         List<PaymentRawBodyValidator> rawBodyValidators,
                                         List<PaymentBodyValidator> bodyValidators) {
        super(headerValidators, rawBodyValidators, bodyValidators, Collections.emptyList());
    }

    @Override
    public String getMethodName() {
        return METHOD_NAME;
    }
}

==> xs2a-impl-3.5-sources.jar: de/adorsys/psd2/xs2a/web/validator/PaymentMethodValidatorImpl.java <==
/*
 * Copyright 2018-2019 adorsys GmbH & Co KG
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package de.adorsys.psd2.xs2a.web.validator;

import de.adorsys.psd2.xs2a.web.validator.body.payment.PaymentBodyValidator;
import de.adorsys.psd2.xs2a.web.validator.header.PaymentHeaderValidator;
import de.adorsys.psd2.xs2a.web.validator.query.QueryParameterValidator;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.Collections;
import java.util.List;

@Component
public class PaymentMethodValidatorImpl extends AbstractMethodValidator<PaymentHeaderValidator, PaymentBodyValidator, QueryParameterValidator> {

    private static final String METHOD_NAME = "_initiatePayment";

    @Autowired
    protected PaymentMethodValidatorImpl(List<PaymentHeaderValidator> headerValidators,
                                         List<PaymentBodyValidator> bodyValidators) {
        super(headerValidators, bodyValidators, Collections.emptyList());
    }

    @Override
    public String getMethodName() {
        return METHOD_NAME;
    }
}
